# Print an optspec for argparse to handle cmd's options that are independent of any subcommand.
function __fish_sq_wot_global_optspecs
	string join \n gpg k/keyring= gpg-keyring network keyserver= r/trust-root= f/format= gpg-ownertrust gossip certification-network a/trust-amount= partial full double time= known-notation= h/help V/version
end

function __fish_sq_wot_needs_command
	# Figure out if the current invocation already has a command.
	set -l cmd (commandline -opc)
	set -e cmd[1]
	argparse -s (__fish_sq_wot_global_optspecs) -- $cmd 2>/dev/null
	or return
	if set -q argv[1]
		# Also print the command, so this can be used to figure out what it is.
		echo $argv[1]
		return 1
	end
	return 0
end

function __fish_sq_wot_using_subcommand
	set -l cmd (__fish_sq_wot_needs_command)
	test -z "$cmd"
	and return 1
	contains -- $cmd[1] $argv
end

complete -c sq-wot -n "__fish_sq_wot_needs_command" -s k -l keyring -d 'Adds KEYRING to the list of keyrings' -r -F
complete -c sq-wot -n "__fish_sq_wot_needs_command" -l keyserver -d 'Sets the keyserver to use to KEYSERVER' -r
complete -c sq-wot -n "__fish_sq_wot_needs_command" -s r -l trust-root -d 'Treats the specified certificate as a trust root' -r
complete -c sq-wot -n "__fish_sq_wot_needs_command" -s f -l format -d 'Render the output in a specific format' -r -f -a "{dot\t'output in graphviz\'s DOT format',human-readable\t'output in human readable format'}"
complete -c sq-wot -n "__fish_sq_wot_needs_command" -s a -l trust-amount -d 'The required amount of trust' -r
complete -c sq-wot -n "__fish_sq_wot_needs_command" -l time -d 'Sets the reference time to TIME' -r
complete -c sq-wot -n "__fish_sq_wot_needs_command" -l known-notation -d 'Adds NOTATION to the list of known notations' -r
complete -c sq-wot -n "__fish_sq_wot_needs_command" -l gpg -d 'Uses gpg\'s keyring and gpg\'s trust roots'
complete -c sq-wot -n "__fish_sq_wot_needs_command" -l gpg-keyring -d 'Adds GnuPG\'s keyring to the list of keyrings'
complete -c sq-wot -n "__fish_sq_wot_needs_command" -l network -d 'Looks up missing certificates over the network'
complete -c sq-wot -n "__fish_sq_wot_needs_command" -l gpg-ownertrust -d 'Causes `sq-wot` to use gpg\'s trust roots as the trust roots'
complete -c sq-wot -n "__fish_sq_wot_needs_command" -l gossip -d 'Treats all certificates as unreliable trust roots'
complete -c sq-wot -n "__fish_sq_wot_needs_command" -l certification-network -d 'Treats the network as a certification network'
complete -c sq-wot -n "__fish_sq_wot_needs_command" -l partial -d 'Require partial authentication'
complete -c sq-wot -n "__fish_sq_wot_needs_command" -l full -d 'Require full authentication'
complete -c sq-wot -n "__fish_sq_wot_needs_command" -l double -d 'Require double authentication'
complete -c sq-wot -n "__fish_sq_wot_needs_command" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c sq-wot -n "__fish_sq_wot_needs_command" -s V -l version -d 'Print version'
complete -c sq-wot -n "__fish_sq_wot_needs_command" -f -a "authenticate" -d 'Authenticate a binding'
complete -c sq-wot -n "__fish_sq_wot_needs_command" -f -a "lookup" -d 'Lookup the certificates associated with a User ID'
complete -c sq-wot -n "__fish_sq_wot_needs_command" -f -a "identify" -d 'Identify a certificate'
complete -c sq-wot -n "__fish_sq_wot_needs_command" -f -a "list" -d 'List all authenticated bindings (User ID and certificate pairs)'
complete -c sq-wot -n "__fish_sq_wot_needs_command" -f -a "path" -d 'Verify the specified path'
complete -c sq-wot -n "__fish_sq_wot_needs_command" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand authenticate" -s k -l keyring -d 'Adds KEYRING to the list of keyrings' -r -F
complete -c sq-wot -n "__fish_sq_wot_using_subcommand authenticate" -l keyserver -d 'Sets the keyserver to use to KEYSERVER' -r
complete -c sq-wot -n "__fish_sq_wot_using_subcommand authenticate" -s r -l trust-root -d 'Treats the specified certificate as a trust root' -r
complete -c sq-wot -n "__fish_sq_wot_using_subcommand authenticate" -s f -l format -d 'Render the output in a specific format' -r -f -a "{dot\t'output in graphviz\'s DOT format',human-readable\t'output in human readable format'}"
complete -c sq-wot -n "__fish_sq_wot_using_subcommand authenticate" -s a -l trust-amount -d 'The required amount of trust' -r
complete -c sq-wot -n "__fish_sq_wot_using_subcommand authenticate" -l time -d 'Sets the reference time to TIME' -r
complete -c sq-wot -n "__fish_sq_wot_using_subcommand authenticate" -l known-notation -d 'Adds NOTATION to the list of known notations' -r
complete -c sq-wot -n "__fish_sq_wot_using_subcommand authenticate" -l email -d 'Changes the USERID parameter to match User IDs with the specified email address'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand authenticate" -l gpg -d 'Uses gpg\'s keyring and gpg\'s trust roots'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand authenticate" -l gpg-keyring -d 'Adds GnuPG\'s keyring to the list of keyrings'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand authenticate" -l network -d 'Looks up missing certificates over the network'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand authenticate" -l gpg-ownertrust -d 'Causes `sq-wot` to use gpg\'s trust roots as the trust roots'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand authenticate" -l gossip -d 'Treats all certificates as unreliable trust roots'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand authenticate" -l certification-network -d 'Treats the network as a certification network'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand authenticate" -l partial -d 'Require partial authentication'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand authenticate" -l full -d 'Require full authentication'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand authenticate" -l double -d 'Require double authentication'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand authenticate" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand lookup" -s k -l keyring -d 'Adds KEYRING to the list of keyrings' -r -F
complete -c sq-wot -n "__fish_sq_wot_using_subcommand lookup" -l keyserver -d 'Sets the keyserver to use to KEYSERVER' -r
complete -c sq-wot -n "__fish_sq_wot_using_subcommand lookup" -s r -l trust-root -d 'Treats the specified certificate as a trust root' -r
complete -c sq-wot -n "__fish_sq_wot_using_subcommand lookup" -s f -l format -d 'Render the output in a specific format' -r -f -a "{dot\t'output in graphviz\'s DOT format',human-readable\t'output in human readable format'}"
complete -c sq-wot -n "__fish_sq_wot_using_subcommand lookup" -s a -l trust-amount -d 'The required amount of trust' -r
complete -c sq-wot -n "__fish_sq_wot_using_subcommand lookup" -l time -d 'Sets the reference time to TIME' -r
complete -c sq-wot -n "__fish_sq_wot_using_subcommand lookup" -l known-notation -d 'Adds NOTATION to the list of known notations' -r
complete -c sq-wot -n "__fish_sq_wot_using_subcommand lookup" -l email -d 'Changes the USERID parameter to match User IDs with the specified email address'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand lookup" -l gpg -d 'Uses gpg\'s keyring and gpg\'s trust roots'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand lookup" -l gpg-keyring -d 'Adds GnuPG\'s keyring to the list of keyrings'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand lookup" -l network -d 'Looks up missing certificates over the network'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand lookup" -l gpg-ownertrust -d 'Causes `sq-wot` to use gpg\'s trust roots as the trust roots'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand lookup" -l gossip -d 'Treats all certificates as unreliable trust roots'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand lookup" -l certification-network -d 'Treats the network as a certification network'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand lookup" -l partial -d 'Require partial authentication'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand lookup" -l full -d 'Require full authentication'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand lookup" -l double -d 'Require double authentication'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand lookup" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand identify" -s k -l keyring -d 'Adds KEYRING to the list of keyrings' -r -F
complete -c sq-wot -n "__fish_sq_wot_using_subcommand identify" -l keyserver -d 'Sets the keyserver to use to KEYSERVER' -r
complete -c sq-wot -n "__fish_sq_wot_using_subcommand identify" -s r -l trust-root -d 'Treats the specified certificate as a trust root' -r
complete -c sq-wot -n "__fish_sq_wot_using_subcommand identify" -s f -l format -d 'Render the output in a specific format' -r -f -a "{dot\t'output in graphviz\'s DOT format',human-readable\t'output in human readable format'}"
complete -c sq-wot -n "__fish_sq_wot_using_subcommand identify" -s a -l trust-amount -d 'The required amount of trust' -r
complete -c sq-wot -n "__fish_sq_wot_using_subcommand identify" -l time -d 'Sets the reference time to TIME' -r
complete -c sq-wot -n "__fish_sq_wot_using_subcommand identify" -l known-notation -d 'Adds NOTATION to the list of known notations' -r
complete -c sq-wot -n "__fish_sq_wot_using_subcommand identify" -l gpg -d 'Uses gpg\'s keyring and gpg\'s trust roots'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand identify" -l gpg-keyring -d 'Adds GnuPG\'s keyring to the list of keyrings'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand identify" -l network -d 'Looks up missing certificates over the network'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand identify" -l gpg-ownertrust -d 'Causes `sq-wot` to use gpg\'s trust roots as the trust roots'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand identify" -l gossip -d 'Treats all certificates as unreliable trust roots'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand identify" -l certification-network -d 'Treats the network as a certification network'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand identify" -l partial -d 'Require partial authentication'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand identify" -l full -d 'Require full authentication'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand identify" -l double -d 'Require double authentication'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand identify" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand list" -s k -l keyring -d 'Adds KEYRING to the list of keyrings' -r -F
complete -c sq-wot -n "__fish_sq_wot_using_subcommand list" -l keyserver -d 'Sets the keyserver to use to KEYSERVER' -r
complete -c sq-wot -n "__fish_sq_wot_using_subcommand list" -s r -l trust-root -d 'Treats the specified certificate as a trust root' -r
complete -c sq-wot -n "__fish_sq_wot_using_subcommand list" -s f -l format -d 'Render the output in a specific format' -r -f -a "{dot\t'output in graphviz\'s DOT format',human-readable\t'output in human readable format'}"
complete -c sq-wot -n "__fish_sq_wot_using_subcommand list" -s a -l trust-amount -d 'The required amount of trust' -r
complete -c sq-wot -n "__fish_sq_wot_using_subcommand list" -l time -d 'Sets the reference time to TIME' -r
complete -c sq-wot -n "__fish_sq_wot_using_subcommand list" -l known-notation -d 'Adds NOTATION to the list of known notations' -r
complete -c sq-wot -n "__fish_sq_wot_using_subcommand list" -l email -d 'Changes the USERID parameter to match User IDs with the specified email address'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand list" -l gpg -d 'Uses gpg\'s keyring and gpg\'s trust roots'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand list" -l gpg-keyring -d 'Adds GnuPG\'s keyring to the list of keyrings'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand list" -l network -d 'Looks up missing certificates over the network'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand list" -l gpg-ownertrust -d 'Causes `sq-wot` to use gpg\'s trust roots as the trust roots'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand list" -l gossip -d 'Treats all certificates as unreliable trust roots'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand list" -l certification-network -d 'Treats the network as a certification network'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand list" -l partial -d 'Require partial authentication'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand list" -l full -d 'Require full authentication'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand list" -l double -d 'Require double authentication'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand list" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand path" -s k -l keyring -d 'Adds KEYRING to the list of keyrings' -r -F
complete -c sq-wot -n "__fish_sq_wot_using_subcommand path" -l keyserver -d 'Sets the keyserver to use to KEYSERVER' -r
complete -c sq-wot -n "__fish_sq_wot_using_subcommand path" -s r -l trust-root -d 'Treats the specified certificate as a trust root' -r
complete -c sq-wot -n "__fish_sq_wot_using_subcommand path" -s f -l format -d 'Render the output in a specific format' -r -f -a "{dot\t'output in graphviz\'s DOT format',human-readable\t'output in human readable format'}"
complete -c sq-wot -n "__fish_sq_wot_using_subcommand path" -s a -l trust-amount -d 'The required amount of trust' -r
complete -c sq-wot -n "__fish_sq_wot_using_subcommand path" -l time -d 'Sets the reference time to TIME' -r
complete -c sq-wot -n "__fish_sq_wot_using_subcommand path" -l known-notation -d 'Adds NOTATION to the list of known notations' -r
complete -c sq-wot -n "__fish_sq_wot_using_subcommand path" -l email -d 'Changes the USERID parameter to match User IDs with the specified email address'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand path" -l gpg -d 'Uses gpg\'s keyring and gpg\'s trust roots'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand path" -l gpg-keyring -d 'Adds GnuPG\'s keyring to the list of keyrings'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand path" -l network -d 'Looks up missing certificates over the network'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand path" -l gpg-ownertrust -d 'Causes `sq-wot` to use gpg\'s trust roots as the trust roots'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand path" -l gossip -d 'Treats all certificates as unreliable trust roots'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand path" -l certification-network -d 'Treats the network as a certification network'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand path" -l partial -d 'Require partial authentication'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand path" -l full -d 'Require full authentication'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand path" -l double -d 'Require double authentication'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand path" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand help; and not __fish_seen_subcommand_from authenticate lookup identify list path help" -f -a "authenticate" -d 'Authenticate a binding'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand help; and not __fish_seen_subcommand_from authenticate lookup identify list path help" -f -a "lookup" -d 'Lookup the certificates associated with a User ID'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand help; and not __fish_seen_subcommand_from authenticate lookup identify list path help" -f -a "identify" -d 'Identify a certificate'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand help; and not __fish_seen_subcommand_from authenticate lookup identify list path help" -f -a "list" -d 'List all authenticated bindings (User ID and certificate pairs)'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand help; and not __fish_seen_subcommand_from authenticate lookup identify list path help" -f -a "path" -d 'Verify the specified path'
complete -c sq-wot -n "__fish_sq_wot_using_subcommand help; and not __fish_seen_subcommand_from authenticate lookup identify list path help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
